import warnings
import argparse
from copy import deepcopy
from lxml import etree as ET

def fix_docbook(filename):
    try:
        tree = ET.parse(filename)
    except:
        warnings.warn("Could not parse file: "+filename)
        return
    root = tree.getroot()
    changed = False
    for im in root.findall(".//{http://docbook.org/ns/docbook}imageobject"):
        if not im.get('role'):
            im.set('role', "html")
            im2 = deepcopy(im)
            im2.set('role', "fo")
            parent = im.getparent()
            parent.insert(parent.index(im)+1, im2)
            changed = True
    if changed:
        tree.write(filename, pretty_print=True, encoding="UTF-8")

def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("file", nargs="*", help="The file(s) to look at")
    args = parser.parse_args()

    for file in args.file:
        fix_docbook(file)

if __name__ == "__main__":
    main()
